@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
+'''base/__init__.py'''
 
 """
-audiotsm.base
-~~~~~~~~~~~~~
-
 This module provides base classes for the implementation of time-scale
 modification procedures.
 """
 
 from .tsm import TSM
-from .analysis_synthesis import AnalysisSynthesisTSM, Converter
+from .analysis_synthesis import AnalysisSynthesisTSM, Converter
\ No newline at end of file
